@@ -79,9 +79,10 @@ class iPdb(Plugin):
                 p = IPython.Debugger.Pdb(ip.options.colors)
 
             p.reset()
-            # inspect.trace() returns a list of frame information from this
-            # frame to the one that raised the exception being treated
-            frame, filename, line, func_name, ctx, idx = inspect.trace()[-1]
+            # inspect.getinnerframes() returns a list of frames information
+            # from this frame to the one that raised the exception being
+            # treated
+            frame, filename, line, func_name, ctx, idx = inspect.getinnerframes(tb)[-1]
             p.interaction(frame, tb)
         finally:
             sys.stdout = stdout
